/**
 * <copyright>
 * 
 * Copyright (c) 2013 itemis and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 *     itemis - Initial API and implementation
 * 
 * </copyright>
 */
package org.safe.examples.editor.pages;

import org.safe.examples.editor.SAFEFormEditor;
import org.eclipse.emf.transaction.TransactionalEditingDomain;
import org.eclipse.emf.transaction.ui.provider.TransactionalAdapterFactoryLabelProvider;
import org.eclipse.jface.viewers.ColumnLabelProvider;
import org.eclipse.jface.viewers.ILabelDecorator;
import org.eclipse.jface.viewers.ILabelProviderListener;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.swt.graphics.Color;
import org.eclipse.swt.graphics.Font;
import org.eclipse.swt.graphics.Image;
import org.safe.examples.common.ui.providers.TypeNameLabelDecorator;

public class AppearanceExampleColumnLabelProvider extends ColumnLabelProvider {

	private final SAFEFormEditor safeFormEditor;

	private final TransactionalAdapterFactoryLabelProvider delegate;
	private final ILabelDecorator typeNameLabelDecorator;

	public AppearanceExampleColumnLabelProvider(SAFEFormEditor safeFormEditor) {
		this.safeFormEditor = safeFormEditor;

		delegate = new TransactionalAdapterFactoryLabelProvider((TransactionalEditingDomain) safeFormEditor.getEditingDomain(),
				safeFormEditor.getAdapterFactory());
		typeNameLabelDecorator = new TypeNameLabelDecorator();
	}

	@Override
	public String getText(Object element) {
		if (element instanceof IStructuredSelection) {
			IStructuredSelection selection = (IStructuredSelection) element;
			element = selection.getFirstElement();
		}

		String text = delegate.getText(element);
		if (safeFormEditor.isShowTypeName()) {
			return typeNameLabelDecorator.decorateText(text, element);
		} else {
			return text;
		}
	}

	@Override
	public String getToolTipText(Object element) {
		String typeName = TypeNameLabelDecorator.getTypeName(element);
		return typeName.length() > 0 ? typeName : null;
	}

	@Override
	public boolean useNativeToolTip(Object object) {
		return true;
	}

	@Override
	public void addListener(ILabelProviderListener listener) {
		delegate.addListener(listener);
	}

	@Override
	public void dispose() {
		delegate.dispose();
	}

	@Override
	public Color getBackground(Object object) {
		return delegate.getBackground(object);
	}

	@Override
	public Font getFont(Object object) {
		return delegate.getFont(object);
	}

	@Override
	public Color getForeground(Object object) {
		return delegate.getForeground(object);
	}

	@Override
	public Image getImage(Object object) {
		return delegate.getImage(object);
	}

	@Override
	public boolean isLabelProperty(Object object, String id) {
		return delegate.isLabelProperty(object, id);
	}

	@Override
	public void removeListener(ILabelProviderListener listener) {
		delegate.removeListener(listener);
	}
}
