/**
 * <copyright>
 * 
 * Copyright (c) 2013 itemis and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 *     itemis - Initial API and implementation
 * 
 * </copyright>
 */
package org.safe.ide.ui.wizards.pages;

import org.eclipse.jface.dialogs.Dialog;
import org.eclipse.jface.dialogs.IDialogConstants;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.sphinx.emf.metamodel.IMetaModelDescriptor;
import org.eclipse.sphinx.emf.workspace.ui.wizards.groups.BasicMetaModelVersionGroup;
import org.eclipse.sphinx.platform.preferences.IProjectWorkspacePreference;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.safe.ide.ui.messages.WorkspaceUIMessages;

public class NewModelProjectNaturePage<T extends IMetaModelDescriptor> extends WizardPage {

	private Composite container;
	protected BasicMetaModelVersionGroup<T> releaseGroup;
	protected IProjectWorkspacePreference<T> projectWorkspacePreference;
	protected T metaModelDescriptor;
	protected String metaModelVersionPreferencePageId;

	/**
	 * Creates a new project creation wizard page for choosing the project nature.
	 * 
	 * @param pageName
	 *            the name of this page
	 */
	public NewModelProjectNaturePage(String pageName,  IProjectWorkspacePreference<T> projectWorkspacePreference, T mmDescriptor, String metaModelVersionPreferencePageId) {
		super(pageName);
		this.projectWorkspacePreference = projectWorkspacePreference;
		this.metaModelDescriptor = mmDescriptor;
		this.metaModelVersionPreferencePageId = metaModelVersionPreferencePageId;
		setPageComplete(false);
	}

	/* (non-Javadoc)
	 * @see org.eclipse.jface.dialogs.IDialogPage#createControl(org.eclipse.swt.widgets.Composite)
	 */
	public void createControl(Composite parent) {
		container = new Composite(parent, SWT.NULL);

		GridLayout gridLayout = new GridLayout(3, false);
		gridLayout.horizontalSpacing = convertHorizontalDLUsToPixels(IDialogConstants.HORIZONTAL_SPACING);
		gridLayout.verticalSpacing = convertVerticalDLUsToPixels(IDialogConstants.VERTICAL_SPACING);
		gridLayout.marginWidth = convertHorizontalDLUsToPixels(IDialogConstants.HORIZONTAL_MARGIN);
		gridLayout.marginHeight = convertVerticalDLUsToPixels(IDialogConstants.VERTICAL_MARGIN);
		container.setLayout(gridLayout);

		setPageComplete(validatePage());
		// Show description on opening
		setErrorMessage(null);
		setMessage(null);
		setControl(container);
		Dialog.applyDialogFont(container);

		releaseGroup =  new BasicMetaModelVersionGroup<T>("ModelProjectNaturePageMetaModelVersionGroup",  metaModelDescriptor, projectWorkspacePreference, metaModelVersionPreferencePageId);
		releaseGroup.setMetaModelVersionLabel(WorkspaceUIMessages.label_metaModelRelease);
		releaseGroup.createContent((Composite) getControl(),3, false);
		Dialog.applyDialogFont(getControl());
	}

	/**
	 * The framework calls this to see if all the files are selected.
	 */
	protected boolean validatePage() {
		setErrorMessage(null);
		return true;
	}

	public IMetaModelDescriptor getRelease() {
		return releaseGroup.getMetaModelVersionDescriptor();
	}

}
