/**
 * <copyright>
 * 
 * Copyright (c) 2013 itemis and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 *     itemis - Initial API and implementation
 * 
 * </copyright>
 */
package org.safe.ide.metamodel;

import org.eclipse.sphinx.emf.metamodel.AbstractMetaModelDescriptor;
import org.eclipse.sphinx.emf.metamodel.IMetaModelDescriptor;

public class SAFEReleaseDescriptor extends AbstractMetaModelDescriptor
	implements Comparable<SAFEReleaseDescriptor> {

	/**
	 * The base name of all SAFE releasel versions.
	 */
	public static final String BASE_NAME = "SAFE"; //$NON-NLS-1$
	
    /**
     * The identifier used for referencing this {@link IMetaModelDescriptor}.
     */
    public static final String ID = "org.safe.metamodel"; //$NON-NLS-1$	

    /**
     * The base namespace of all SAFE meta models.
     */
    public static final String BASE_NAMESPACE = "http://safe-project.eu"; //$NON-NLS-1$

    /**
     * The id of release-independent base content type for all release-specific
     * SAFE XMI file content types.
     */
    public static final String SAFE_BASE_CONTENT_TYPE_ID = "org.safe.metamodel.safeXMIFile"; //$NON-NLS-1$

    /**
     * The default file extension used for SAFE XMI files.
     */
    public static final String SAFE_DEFAULT_FILE_EXTENSION = "safe"; //$NON-NLS-1$

    /**
     * Singleton instance.
     */
    public static final SAFEReleaseDescriptor INSTANCE = new SAFEReleaseDescriptor();

    protected SAFEMetaModelVersionData safeVersionData;

    /**
     * Private default constructor for singleton pattern.
     */
    private SAFEReleaseDescriptor() {
    	super(ID, BASE_NAMESPACE, BASE_NAME);
    }

    protected SAFEReleaseDescriptor(String identifier,
	    SAFEMetaModelVersionData versionData) {
	super(identifier, BASE_NAMESPACE, versionData);

	safeVersionData = versionData;
    }

    /*
     * @see org.eclipse.sphinx.emf.metamodel.AbstractMetaModelDescriptor#
     * getDefaultContentTypeId()
     */
    @Override
    public String getDefaultContentTypeId() {
	return SAFE_BASE_CONTENT_TYPE_ID;
    }

    public SAFEMetaModelVersionData getSAFEVersionData() {
	return safeVersionData;
    }

    /*
     * @see java.lang.Comparable#compareTo(java.lang.Object)
     */
    public int compareTo(SAFEReleaseDescriptor other) {
	return safeVersionData.compareTo(other.safeVersionData);
    }
}
