/**
 * <copyright>
 * 
 * Copyright (c) 2013 itemis and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 *     itemis - Initial API and implementation
 * 
 * </copyright>
 */
package org.safe.ide.preferences;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

import org.safe.ide.internal.Activator;
import org.safe.ide.metamodel.SAFEReleaseDescriptor;
import org.eclipse.core.runtime.preferences.AbstractPreferenceInitializer;
import org.eclipse.core.runtime.preferences.DefaultScope;
import org.eclipse.core.runtime.preferences.IEclipsePreferences;
import org.eclipse.sphinx.emf.metamodel.MetaModelDescriptorRegistry;
import org.eclipse.sphinx.platform.util.PlatformLogUtil;

public class SAFEPreferenceInitializer extends AbstractPreferenceInitializer {

    @Override
    public void initializeDefaultPreferences() {
	IEclipsePreferences defaultPreferences = getDefaultPreferences();
	if (defaultPreferences == null) {
		RuntimeException ex = new RuntimeException(
				"Failed to retrieve default preferences for " + SAFEReleaseDescriptor.INSTANCE.getName() + "."); //$NON-NLS-1$ //$NON-NLS-2$
		PlatformLogUtil.logAsWarning(Activator.getPlugin(), ex);
	}

	// Default for release group
	defaultPreferences.put(ISAFEPreferenceConstants.PREF_SAFE_RELEASE, ISAFEPreferenceConstants.PREF_SAFE_RELEASE_DEFAULT);
	defaultPreferences.put(ISAFEPreferenceConstants.PREF_SAFE_RESOURCE_VERSION,
		ISAFEPreferenceConstants.PREF_SAFE_RESOURCE_VERSION_DEFAULT);
    }
    
    /**
     * Returns the {@link IEclipsePreferences default preferences} for SAFE.
     * 
     * @return The {@link IEclipsePreferences default preferences} for SAFE
     *         or <code>null</code> if no such could be determined.
     */
    private IEclipsePreferences getDefaultPreferences() {
	DefaultScope defaultScope = new DefaultScope();
	return defaultScope.getNode(Activator.getPlugin().getSymbolicName());
    }
    
    /**
     * Returns the id of the most recent {@link SAFEReleaseDescriptor SAFE
     * release descriptor} as default.
     * 
     * @return The default value for
     *         {@link ISAFEPreferenceConstants#PREF_SAFE_RELEASE} or an
     *         empty string if no such could be determined.
     */
    public static String getSAFEReleaseDefault() {
	List<SAFEReleaseDescriptor> descriptors = MetaModelDescriptorRegistry.INSTANCE
		.getDescriptors(SAFEReleaseDescriptor.INSTANCE);

	if (descriptors.size() == 0) {
	    return ""; //$NON-NLS-1$
	}

	List<SAFEReleaseDescriptor> sortedDescriptors = new ArrayList<SAFEReleaseDescriptor>(
		descriptors);

	Collections.sort(sortedDescriptors);

	return sortedDescriptors.get(sortedDescriptors.size() - 1)
		.getIdentifier();
    }

}

