/**
 * <copyright>
 * </copyright>
 *
 * $Id$
 */
package safe10.classmodel.errormodel;

import org.eclipse.emf.ecore.EObject;

import safe10.classmodel.errormodel._instanceref.MalfunctionInstanceRef;

/**
 * <!-- begin-user-doc -->
 * A representation of the model object '<em><b>Error Model Mapping</b></em>'.
 * <!-- end-user-doc -->
 *
 * <!-- begin-model-doc -->
 * Via the class ErrorModelMapping it is possible to map malfunctions of one abstraction level (e.g. EAST ADL implementation level) to another level of abstraction (e.g. EAST ADL analysis level). This way the correlation between different levels of abstraction can be made explicit.
 * 
 * The ErrorModelMapping shall be attached to the "lower" level of abstraction. Example:
 * <ul>
 * 	<li>a malfunction defined for a software component (implementation level) shall be related with a malfunction defined on design level</li>
 * </ul>
 * <ul>
 * 	<li>in this case, (at least) two instances of SafetyExtensions (TechnicalSafetyExtension, AutosarSystemSafetyExtension) exist. In each of them an ErrorModelType is defined containing the before mentioned malfunctions</li>
 * </ul>
 * <ul>
 * 	<li>in the AutosarSystemSafetyExtension, we define an ErrorModelMapping and relate the software malfunction (in the role of "origin") to the malfunction defined within the TechnicalSafetyExtension (in the role "target")</li>
 * </ul>
 * 
 * Thus, the following rules shall be applied:
 * <ul>
 * 	<li>the MalfunctionPrototype referenced via the "origin" relationship shall be defined within the same SafetyExtension as an instance of this class</li>
 * 	<li>the MalfunctionPrototype referecnes via the "target" relationship shall be defined within a SafetyExtension which corresponds to a higher level of abstraction</li>
 * </ul>
 * <!-- end-model-doc -->
 *
 * <p>
 * The following features are supported:
 * <ul>
 *   <li>{@link safe10.classmodel.errormodel.ErrorModelMapping#getOrigin <em>Origin</em>}</li>
 *   <li>{@link safe10.classmodel.errormodel.ErrorModelMapping#getTarget <em>Target</em>}</li>
 * </ul>
 * </p>
 *
 * @see safe10.classmodel.errormodel.ErrormodelPackage#getErrorModelMapping()
 * @model annotation="MetaData guid='{1E5BA56F-DE0C-436a-8E4D-D469454544C5}' id='1363688014' EA\040name='ErrorModelMapping'"
 *        annotation="TaggedValues xml.name='ERROR-MODEL-MAPPING' xml.namePlural='ERROR-MODEL-MAPPINGS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1'"
 *        annotation="EAAdapter metaModelType='SAFE'"
 * @generated
 */
public interface ErrorModelMapping extends EObject
{
  /**
   * Returns the value of the '<em><b>Origin</b></em>' containment reference.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Origin</em>' containment reference isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Origin</em>' containment reference.
   * @see #setOrigin(MalfunctionInstanceRef)
   * @see safe10.classmodel.errormodel.ErrormodelPackage#getErrorModelMapping_Origin()
   * @model containment="true" required="true"
   *        annotation="MetaData guid='{4028C1DF-34B0-4055-A9C3-27A300D6D151}' id='594040086' EA\040name=''"
   *        annotation="TaggedValues xml.name='ORIGIN-IREF' xml.namePlural='ORIGIN-IREFS' xml.roleElement='true' xml.typeElement='false' xml.typeWrapperElement='false' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1' xml.roleWrapperElement='false'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   */
  MalfunctionInstanceRef getOrigin();

  /**
   * Sets the value of the '{@link safe10.classmodel.errormodel.ErrorModelMapping#getOrigin <em>Origin</em>}' containment reference.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Origin</em>' containment reference.
   * @see #getOrigin()
   * @generated
   */
  void setOrigin(MalfunctionInstanceRef value);

  /**
   * Returns the value of the '<em><b>Target</b></em>' containment reference.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Target</em>' containment reference isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Target</em>' containment reference.
   * @see #setTarget(MalfunctionInstanceRef)
   * @see safe10.classmodel.errormodel.ErrormodelPackage#getErrorModelMapping_Target()
   * @model containment="true" required="true"
   *        annotation="MetaData guid='{FB75537C-5F4C-487b-B5B5-5259ECF38490}' id='1296611551' EA\040name=''"
   *        annotation="TaggedValues xml.name='TARGET-IREF' xml.namePlural='TARGET-IREFS' xml.roleElement='true' xml.typeElement='false' xml.typeWrapperElement='false' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1' xml.roleWrapperElement='false'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   */
  MalfunctionInstanceRef getTarget();

  /**
   * Sets the value of the '{@link safe10.classmodel.errormodel.ErrorModelMapping#getTarget <em>Target</em>}' containment reference.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Target</em>' containment reference.
   * @see #getTarget()
   * @generated
   */
  void setTarget(MalfunctionInstanceRef value);

} // ErrorModelMapping
