/**
 * <copyright>
 * </copyright>
 *
 * $Id$
 */
package safe10.classmodel.errormodel.errormodeltype;

import org.eclipse.emf.ecore.EObject;

import safe10.classmodel.errormodel._instanceref.MalfunctionInstanceRef;

/**
 * <!-- begin-user-doc -->
 * A representation of the model object '<em><b>Fault Failure Propagation Link</b></em>'.
 * <!-- end-user-doc -->
 *
 * <!-- begin-model-doc -->
 * The FaultFailurePropagationLink metaclass represents the links for the propagations of faults/failures across system elements. In particular, it defines that one error model provides the faults/failures that another error model receives.
 * 
 * A fault/failure link can only be applied to compatible ports, either for fault/failure delegation within an error model or for fault/failure transmission across two error models. A FaultFailurePropagationLink can only connect fault/failures that have compatible types. 
 * 
 * Constraints:
 * [1] Only compatible cause-effect pairs may be connected.
 * 
 * [2] Two fault/failure are compatible if the MalfunctionType of the cause represents a subset of the MalfunctionType set represented by the MalfunctionType of the effect. 
 * 
 * Semantics:
 * The FaultFailurePropagationLink defines a Failure propagation path, from the cause on one error model to the effect of another error model. 
 * 
 * 
 * Extension:
 * UML::Connector
 * <!-- end-model-doc -->
 *
 * <p>
 * The following features are supported:
 * <ul>
 *   <li>{@link safe10.classmodel.errormodel.errormodeltype.FaultFailurePropagationLink#getImmediatePropagation <em>Immediate Propagation</em>}</li>
 *   <li>{@link safe10.classmodel.errormodel.errormodeltype.FaultFailurePropagationLink#getEffect <em>Effect</em>}</li>
 *   <li>{@link safe10.classmodel.errormodel.errormodeltype.FaultFailurePropagationLink#getCause <em>Cause</em>}</li>
 * </ul>
 * </p>
 *
 * @see safe10.classmodel.errormodel.errormodeltype.ErrormodeltypePackage#getFaultFailurePropagationLink()
 * @model annotation="MetaData guid='{DE9FADCA-2350-4456-BDF4-B923CAD341A1}' id='-601828299' EA\040name='FaultFailurePropagationLink'"
 *        annotation="TaggedValues xml.name='FAULT-FAILURE-PROPAGATION-LINK' xml.namePlural='FAULT-FAILURE-PROPAGATION-LINKS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1'"
 *        annotation="EAAdapter metaModelType='SAFE'"
 * @generated
 */
public interface FaultFailurePropagationLink extends EObject
{
  /**
   * Returns the value of the '<em><b>Immediate Propagation</b></em>' attribute.
   * The default value is <code>"false"</code>.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Immediate Propagation</em>' attribute isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Immediate Propagation</em>' attribute.
   * @see #isSetImmediatePropagation()
   * @see #unsetImmediatePropagation()
   * @see #setImmediatePropagation(Boolean)
   * @see safe10.classmodel.errormodel.errormodeltype.ErrormodeltypePackage#getFaultFailurePropagationLink_ImmediatePropagation()
   * @model default="false" unsettable="true" dataType="safe10.classmodel.commonstructure.datatypes.Boolean" required="true"
   *        annotation="MetaData guid='{A241B878-36FC-46ad-9E33-4A964ED996D2}' id='-189994158' EA\040name='immediatePropagation'"
   *        annotation="TaggedValues xml.name='IMMEDIATE-PROPAGATION' xml.namePlural='IMMEDIATE-PROPAGATIONS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1' xml.roleElement='true' xml.roleWrapperElement='false' xml.typeElement='false' xml.typeWrapperElement='false'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   */
  Boolean getImmediatePropagation();

  /**
   * Sets the value of the '{@link safe10.classmodel.errormodel.errormodeltype.FaultFailurePropagationLink#getImmediatePropagation <em>Immediate Propagation</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Immediate Propagation</em>' attribute.
   * @see #isSetImmediatePropagation()
   * @see #ImmediatePropagation()
   * @see #getImmediatePropagation()
   * @generated
   */
  void setImmediatePropagation(Boolean value);

  /**
   * Unsets the value of the '{@link safe10.classmodel.errormodel.errormodeltype.FaultFailurePropagationLink#getImmediatePropagation <em>Immediate Propagation</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #isSetImmediatePropagation()
   * @see #getImmediatePropagation()
   * @see #setImmediatePropagation(Boolean)
   * @generated
   */
  void unsetImmediatePropagation();

  /**
   * Returns whether the value of the '{@link safe10.classmodel.errormodel.errormodeltype.FaultFailurePropagationLink#getImmediatePropagation <em>Immediate Propagation</em>}' attribute is set.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @return whether the value of the '<em>Immediate Propagation</em>' attribute is set.
   * @see #ImmediatePropagation()
   * @see #getImmediatePropagation()
   * @see #setImmediatePropagation(Boolean)
   * @generated
   */
  boolean isSetImmediatePropagation();

  /**
   * Returns the value of the '<em><b>Effect</b></em>' containment reference.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Effect</em>' containment reference isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Effect</em>' containment reference.
   * @see #setEffect(MalfunctionInstanceRef)
   * @see safe10.classmodel.errormodel.errormodeltype.ErrormodeltypePackage#getFaultFailurePropagationLink_Effect()
   * @model containment="true" required="true"
   *        annotation="MetaData guid='{3EE23176-F21B-4b3d-9B71-D4F59D5C028C}' id='-233431452' EA\040name=''"
   *        annotation="TaggedValues xml.name='EFFECT-IREF' xml.namePlural='EFFECT-IREFS' xml.roleElement='true' xml.typeElement='false' xml.typeWrapperElement='false' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1' xml.roleWrapperElement='false'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   */
  MalfunctionInstanceRef getEffect();

  /**
   * Sets the value of the '{@link safe10.classmodel.errormodel.errormodeltype.FaultFailurePropagationLink#getEffect <em>Effect</em>}' containment reference.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Effect</em>' containment reference.
   * @see #getEffect()
   * @generated
   */
  void setEffect(MalfunctionInstanceRef value);

  /**
   * Returns the value of the '<em><b>Cause</b></em>' containment reference.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Cause</em>' containment reference isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Cause</em>' containment reference.
   * @see #setCause(MalfunctionInstanceRef)
   * @see safe10.classmodel.errormodel.errormodeltype.ErrormodeltypePackage#getFaultFailurePropagationLink_Cause()
   * @model containment="true" required="true"
   *        annotation="MetaData guid='{CE83B388-EC4A-4ce9-B8B7-989C598D8FD3}' id='-222555062' EA\040name=''"
   *        annotation="TaggedValues xml.name='CAUSE-IREF' xml.namePlural='CAUSE-IREFS' xml.roleElement='true' xml.typeElement='false' xml.typeWrapperElement='false' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1' xml.roleWrapperElement='false'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   */
  MalfunctionInstanceRef getCause();

  /**
   * Sets the value of the '{@link safe10.classmodel.errormodel.errormodeltype.FaultFailurePropagationLink#getCause <em>Cause</em>}' containment reference.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Cause</em>' containment reference.
   * @see #getCause()
   * @generated
   */
  void setCause(MalfunctionInstanceRef value);

} // FaultFailurePropagationLink
