/**
 * <copyright>
 * </copyright>
 *
 * $Id$
 */
package safe10.classmodel.hardware.failureformula;

import safe10.classmodel.commonstructure.formulaexpression.AtpFormulaExpressionString;

import safe10.classmodel.hardware.failure.HWFailureMode;
import safe10.classmodel.hardware.failure.HWFailureRate;
import safe10.classmodel.hardware.failure.HWFault;

/**
 * <!-- begin-user-doc -->
 * A representation of the model object '<em><b>HWFM Single Contribution Formula</b></em>'.
 * <!-- end-user-doc -->
 *
 * <!-- begin-model-doc -->
 * This class describes the individual contribution of an HWFailureMode of a HWComponent to ResidualFault, SinglePointFault or Multiple Fault Latent (in FIT). It is assumed that the HWFailureMode lead to the top level malfunction (link to violation of a SafetyGoal) given by the relation to HWFault connected to a malfunction.
 * 
 * The formula expression shall be for each FailureMode of a safety-related HwComponent (part of the item).
 * 
 * SinglePointFault represents a first order fault, while DualPointFault
 * 
 * lambdaSafetyComponent = Value(HWFailureRate)
 * SafetyComponentName = HardwareComponent Class name // to allow detect multiple counting of lambdaSafetyComponent
 * 
 * If (HWFault == SafeFault)
 * lambdaSafeFault(HWFMSingleContribution) = [Value(HWFailureRate)*failureRateDistribution(HWFailureMode) ]   
 * Else
 * lambdaSafeFault(HWFMSingleContribution) = 0
 * Endif
 * 
 * If (HWFault == SinglePointFault) 
 * lambdaSinglePointFault(HWFMSingleContribution) = [Value(HWFailureRate)*failureRateDistribution(HWFailureMode) ]
 * Else lambdaSinglePointFault(HWFMSingleContribution) = 0
 * Endif
 * 
 * If (HWFault == DualPointFault)
 *        If   (HWSafetyMechanism covers the FailureMode) //residual Fault as HWFailureMode.HWSafetyMechanism = null 
 * lambdaResidualFault(HWFMSingleContribution) = [ Value(HWFailureRate)*failureRateDistribution(HWFailureMode) ]  * [hwDiagnosisCoverageRF(HWSafetyMechanism/100 ]
 * lambdaMultiplePointFaultLatent(HWFMSingleContribution) = [ Value(HWFailureRate) * failureRateDistribution(HWFailureMode) * hwDiagnosisCoverageRF(HWSafetyMechanism) ] *  [ ( 1 - hwDiagnosisCoverageLF(HWSafetyMechanism)/100) ]
 *        Else
 * lambdaResidualFault(HWFMSingleContribution) = 0 
 * lambdaMultiplePointFaultLatent(HWFMSingleContribution) = [ Value(HWFailureRate) * failureRateDistribution(HWFailureMode) ] * Other Component Failure Rate
 * Endif
 * 
 * Notes that value(HWFailureRate) and failureRateDistribution(HWFailureMode) are applied on the calculated value extracted from electronic design level  to perform the final calculation and verification of the architectural hardware metrics and probabilistic evaluation of violation of the safety goal. The selection between allocated and calculated value is a tool feature that allow first a calculation for estimation based on allocation field of failure rate and distribution, and then verification based on HWComponentQuantifiedFMFromPartHWPart as extract from Part Analysis gives directly the lambda of the HWFailiure Mode as HWFailureRate*FailureRateDistribution thanks to the relation to HWFault.
 * 
 * 
 * <!-- end-model-doc -->
 *
 * <p>
 * The following features are supported:
 * <ul>
 *   <li>{@link safe10.classmodel.hardware.failureformula.HWFMSingleContributionFormula#getFailureRateDistribution <em>Failure Rate Distribution</em>}</li>
 *   <li>{@link safe10.classmodel.hardware.failureformula.HWFMSingleContributionFormula#getHwFaultTypeValue <em>Hw Fault Type Value</em>}</li>
 *   <li>{@link safe10.classmodel.hardware.failureformula.HWFMSingleContributionFormula#getHwFailureRateValue <em>Hw Failure Rate Value</em>}</li>
 * </ul>
 * </p>
 *
 * @see safe10.classmodel.hardware.failureformula.FailureformulaPackage#getHWFMSingleContributionFormula()
 * @model annotation="MetaData guid='{1FA8D095-DA80-47b2-A7B9-19160816335D}' id='-371920057' EA\040name='HWFMSingleContributionFormula'"
 *        annotation="TaggedValues xml.name='HWFM-SINGLE-CONTRIBUTION-FORMULA' xml.namePlural='HWFM-SINGLE-CONTRIBUTION-FORMULAS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1'"
 *        annotation="EAAdapter metaModelType='SAFE'"
 * @generated
 */
public interface HWFMSingleContributionFormula extends AtpFormulaExpressionString
{
  /**
   * Returns the value of the '<em><b>Failure Rate Distribution</b></em>' reference.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Failure Rate Distribution</em>' reference isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Failure Rate Distribution</em>' reference.
   * @see #setFailureRateDistribution(HWFailureMode)
   * @see safe10.classmodel.hardware.failureformula.FailureformulaPackage#getHWFMSingleContributionFormula_FailureRateDistribution()
   * @model required="true"
   *        annotation="MetaData guid='{4E2CF278-B4BF-435c-A47C-67F6BB6BD1B5}' id='-1180107483' EA\040name=''"
   *        annotation="TaggedValues xml.name='FAILURE-RATE-DISTRIBUTION-REF' xml.namePlural='FAILURE-RATE-DISTRIBUTION-REFS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1' xml.roleElement='true' xml.roleWrapperElement='false' xml.typeElement='false' xml.typeWrapperElement='false'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   */
  HWFailureMode getFailureRateDistribution();

  /**
   * Sets the value of the '{@link safe10.classmodel.hardware.failureformula.HWFMSingleContributionFormula#getFailureRateDistribution <em>Failure Rate Distribution</em>}' reference.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Failure Rate Distribution</em>' reference.
   * @see #getFailureRateDistribution()
   * @generated
   */
  void setFailureRateDistribution(HWFailureMode value);

  /**
   * Returns the value of the '<em><b>Hw Fault Type Value</b></em>' reference.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Hw Fault Type Value</em>' reference isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Hw Fault Type Value</em>' reference.
   * @see #setHwFaultTypeValue(HWFault)
   * @see safe10.classmodel.hardware.failureformula.FailureformulaPackage#getHWFMSingleContributionFormula_HwFaultTypeValue()
   * @model required="true"
   *        annotation="MetaData guid='{FBF2B5AB-60AF-468c-91BE-7B7D74EBD578}' id='-966541950' EA\040name=''"
   *        annotation="TaggedValues xml.name='HW-FAULT-TYPE-VALUE-REF' xml.namePlural='HW-FAULT-TYPE-VALUE-REFS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1' xml.roleElement='true' xml.roleWrapperElement='false' xml.typeElement='false' xml.typeWrapperElement='false'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   */
  HWFault getHwFaultTypeValue();

  /**
   * Sets the value of the '{@link safe10.classmodel.hardware.failureformula.HWFMSingleContributionFormula#getHwFaultTypeValue <em>Hw Fault Type Value</em>}' reference.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Hw Fault Type Value</em>' reference.
   * @see #getHwFaultTypeValue()
   * @generated
   */
  void setHwFaultTypeValue(HWFault value);

  /**
   * Returns the value of the '<em><b>Hw Failure Rate Value</b></em>' reference.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Hw Failure Rate Value</em>' reference isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Hw Failure Rate Value</em>' reference.
   * @see #setHwFailureRateValue(HWFailureRate)
   * @see safe10.classmodel.hardware.failureformula.FailureformulaPackage#getHWFMSingleContributionFormula_HwFailureRateValue()
   * @model required="true"
   *        annotation="MetaData guid='{DCFF2BC6-491E-47d4-AD47-A1DACF93DE6D}' id='-748113898' EA\040name=''"
   *        annotation="TaggedValues xml.name='HW-FAILURE-RATE-VALUE-REF' xml.namePlural='HW-FAILURE-RATE-VALUE-REFS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1' xml.roleElement='true' xml.roleWrapperElement='false' xml.typeElement='false' xml.typeWrapperElement='false'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   */
  HWFailureRate getHwFailureRateValue();

  /**
   * Sets the value of the '{@link safe10.classmodel.hardware.failureformula.HWFMSingleContributionFormula#getHwFailureRateValue <em>Hw Failure Rate Value</em>}' reference.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Hw Failure Rate Value</em>' reference.
   * @see #getHwFailureRateValue()
   * @generated
   */
  void setHwFailureRateValue(HWFailureRate value);

} // HWFMSingleContributionFormula
