/**
 * <copyright>
 * </copyright>
 *
 * $Id$
 */
package safe10.classmodel.hardware.failureformula;

import org.eclipse.emf.common.util.EList;

import safe10.classmodel.commonstructure.formulaexpression.AtpFormulaExpressionString;

import safe10.classmodel.hardware.hwquantitativemeasure.HWFMSingleContribution;

/**
 * <!-- begin-user-doc -->
 * A representation of the model object '<em><b>HW Failure Class Contribution Formula</b></em>'.
 * <!-- end-user-doc -->
 *
 * <!-- begin-model-doc -->
 * This class describes the calculation of the diagnostic coverage of a HWElement (from HWComponent) for the Failure Rate Class method (in %) as ratio of all fault coverage of the HW Component (safe fault, single-point fault and residual fault) and the calculation of the element FailureRateClass defined by its failure rate.
 * 
 * The formula expression shall be calculated for each FailureMode of a safety-related HwComponent (part of the item).
 * 
 * HW Element Failure Rate Class = Failure Class (safety-related failure rate component)
 * HW Element Residual Diagnostic Coverage  = 100% - total (single point faults failure rate + residual faults failure rate) /safety related failure rate component
 * HW Element Latent Diagnostic Coverage  = 100% - total(multiple fault latent) / ((safety related failure rate component) - total (single point faults failure rate + residual faults failure rate))
 * 
 * The formula expression shall be for each the top level malfunction (link to violation of the SafetyGoal).
 * HWElementFailureRateClass(HWElementFailureClass) = HWValueRateClassEnum(LambdaSafetyComponent )
 * HWElementFailureRateClass(HWElementResidualDiagnosisCoverage) = { 1 - [  ( Sum (lambdaSinglePointFault(HWFMSingleContribution) + lambdaResidualFault(HWFMSingleContribution) ) / LambdaSafetyComponent ] } * 100 
 * 
 * HWElementFailureRateClass(HWElementLatentDiagnosisCoverage) = { 1 - [ Sum (lambdaMultipleFaultLatent(HWFMSingleContribution) /  [ LambdaSafetyComponent - Sum ( lambdaSinglePointFault(HWFMSingleContribution) + lambdaResidualFault(HWFMSingleContribution)  ] ]  } * 100 
 * 
 * Note that Value(hwElementDiagnosisCoverage) is applied on estimatedValue  from electronic design level  to perform the final calculation and verification of the  individual HWElement FailureRateClass and ElementDiagnosisCoverage.  The selection between calculated and estimated value is a tool feature that allow first a calculation for estimation based on allocation field of failure rate. Only safety-related component are considered and LambdaSafetyComponent is only counted once for a HWElement (identical safetyComponentClassName).
 * <!-- end-model-doc -->
 *
 * <p>
 * The following features are supported:
 * <ul>
 *   <li>{@link safe10.classmodel.hardware.failureformula.HWFailureClassContributionFormula#getLambdaValue <em>Lambda Value</em>}</li>
 * </ul>
 * </p>
 *
 * @see safe10.classmodel.hardware.failureformula.FailureformulaPackage#getHWFailureClassContributionFormula()
 * @model annotation="MetaData guid='{0F0E1310-EAA6-4b5f-BEC9-2F83A1ED46D8}' id='465603964' EA\040name='HWFailureClassContributionFormula'"
 *        annotation="TaggedValues xml.name='HW-FAILURE-CLASS-CONTRIBUTION-FORMULA' xml.namePlural='HW-FAILURE-CLASS-CONTRIBUTION-FORMULAS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1'"
 *        annotation="EAAdapter metaModelType='SAFE'"
 * @generated
 */
public interface HWFailureClassContributionFormula extends AtpFormulaExpressionString
{
  /**
   * Returns the value of the '<em><b>Lambda Value</b></em>' reference list.
   * The list contents are of type {@link safe10.classmodel.hardware.hwquantitativemeasure.HWFMSingleContribution}.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Lambda Value</em>' reference list isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Lambda Value</em>' reference list.
   * @see safe10.classmodel.hardware.failureformula.FailureformulaPackage#getHWFailureClassContributionFormula_LambdaValue()
   * @model annotation="MetaData guid='{0DA7C4A9-839E-426b-8F28-42E632CA821E}' id='1792618403' EA\040name=''"
   *        annotation="TaggedValues xml.name='LAMBDA-VALUE-REF' xml.namePlural='LAMBDA-VALUE-REFS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1' xml.roleElement='true' xml.roleWrapperElement='true' xml.typeElement='false' xml.typeWrapperElement='false'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   */
  EList<HWFMSingleContribution> getLambdaValue();

} // HWFailureClassContributionFormula
