/**
 * <copyright>
 * </copyright>
 *
 * $Id$
 */
package safe10.classmodel.hardware.failureformula;

import org.eclipse.emf.common.util.EList;

import safe10.classmodel.commonstructure.formulaexpression.AtpFormulaExpressionString;

import safe10.classmodel.hardware.hwquantitativemeasure.HWFMSingleContribution;

/**
 * <!-- begin-user-doc -->
 * A representation of the model object '<em><b>HWPMHF Formula</b></em>'.
 * <!-- end-user-doc -->
 *
 * <!-- begin-model-doc -->
 * This class describes the individual PMHF (in FIT) as probabilistic evaluation of violation of a top level malfunction (link to violation of a SafetyGoal).
 * 
 * PMHF = single point faults failure rate + residual faults failure rate + (total safety related faults failure rate / 10<sup>-9</sup> * delta) * latent multiple point faults failure rate
 * 
 * The formula expression shall be for each SafetyGoal:
 * Value(HWPMHF) = [ Sum (lambdaSinglePointFault(HWFMSingleContribution) + lambdaResidualFault(HWFMSingleContribution)) ] + [ Sum(LambdaSafetyComponent)  *  1.10-9  * exposureTime(HWPMHF) * lambdaMultiplePointLatent(HWFMSingleContribution) ]
 * 
 * Value(HWPMHF) is applied on calculatedValue extracted from electronic design level  for final calculation and verification of the final PMHF probability.  The selection between calculated and estimated value is a tool feature that allow first a calculation for estimation based on allocation field of failure rate and distribution. Only Component safety relevant are considered.
 * Sum(xxxxValue(xxxxLambdaSafetyComponent) is applied for estimated and calculated, and only counted once (identical safetyComponentClassName).
 * <!-- end-model-doc -->
 *
 * <p>
 * The following features are supported:
 * <ul>
 *   <li>{@link safe10.classmodel.hardware.failureformula.HWPMHFFormula#getLambdaValue <em>Lambda Value</em>}</li>
 * </ul>
 * </p>
 *
 * @see safe10.classmodel.hardware.failureformula.FailureformulaPackage#getHWPMHFFormula()
 * @model annotation="MetaData guid='{7683EBCA-B75E-4384-9B1D-03A4C062085B}' id='-304705806' EA\040name='HWPMHFFormula'"
 *        annotation="TaggedValues xml.name='HWPMHF-FORMULA' xml.namePlural='HWPMHF-FORMULAS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1'"
 *        annotation="EAAdapter metaModelType='SAFE'"
 * @generated
 */
public interface HWPMHFFormula extends AtpFormulaExpressionString
{
  /**
   * Returns the value of the '<em><b>Lambda Value</b></em>' reference list.
   * The list contents are of type {@link safe10.classmodel.hardware.hwquantitativemeasure.HWFMSingleContribution}.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Lambda Value</em>' reference list isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Lambda Value</em>' reference list.
   * @see safe10.classmodel.hardware.failureformula.FailureformulaPackage#getHWPMHFFormula_LambdaValue()
   * @model annotation="MetaData guid='{AAF45E4E-435D-4f9d-92FB-6F963ED88BDA}' id='-2018950031' EA\040name=''"
   *        annotation="TaggedValues xml.name='LAMBDA-VALUE-REF' xml.namePlural='LAMBDA-VALUE-REFS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1' xml.roleElement='true' xml.roleWrapperElement='true' xml.typeElement='false' xml.typeWrapperElement='false'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   */
  EList<HWFMSingleContribution> getLambdaValue();

} // HWPMHFFormula
