/**
 * <copyright>
 * </copyright>
 *
 * $Id$
 */
package safe10.classmodel.hardware.failureformula;

import org.eclipse.emf.common.util.EList;

import safe10.classmodel.commonstructure.formulaexpression.AtpFormulaExpressionString;

import safe10.classmodel.hardware.hwquantitativemeasure.HWFMSingleContribution;

/**
 * <!-- begin-user-doc -->
 * A representation of the model object '<em><b>HW Single Point Fault Metric Formula</b></em>'.
 * <!-- end-user-doc -->
 *
 * <!-- begin-model-doc -->
 * This class describes the the single-point fault metric (in %) as ratio of impact of single-point and residual faults for a top level malfunction (link to violation of a SafetyGoal).
 * 
 * SPF metric  = 100% - total (single point faults failure rate + residual faults failure rate)  / total (safety related HWComponent failure rate) 
 * 
 * The formula expression shall be for each SafetyGoal:
 * Value(SinglePointFaultMetric) = { 1 - [  ( Sum (lambdaSinglePointFault(FMSingleContribution) + lambdaResidualFault(FMSingleContribution) ) / Sum(LambdaSafetyComponent) ] } * 100 
 * 
 * Value(SinglePointFaultMetric) is applied on estimatedValue from electronic design level for final calculation and verification of the final single-point fault metric.  The selection between calculated and estimated value is a tool feature that allow first a calculation for estimation based on allocation field of failure rate and distribution. Only safety-related HWComponent are considered.
 * 
 * Sum(LambdaSafetyComponent) is  only counted once for a HWElement (identical safetyComponentClassName).
 * <!-- end-model-doc -->
 *
 * <p>
 * The following features are supported:
 * <ul>
 *   <li>{@link safe10.classmodel.hardware.failureformula.HWSinglePointFaultMetricFormula#getLambdaValue <em>Lambda Value</em>}</li>
 * </ul>
 * </p>
 *
 * @see safe10.classmodel.hardware.failureformula.FailureformulaPackage#getHWSinglePointFaultMetricFormula()
 * @model annotation="MetaData guid='{3BD6B877-C198-4fd7-A4B1-D730BF92CB11}' id='1341232752' EA\040name='HWSinglePointFaultMetricFormula'"
 *        annotation="TaggedValues xml.name='HW-SINGLE-POINT-FAULT-METRIC-FORMULA' xml.namePlural='HW-SINGLE-POINT-FAULT-METRIC-FORMULAS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1'"
 *        annotation="EAAdapter metaModelType='SAFE'"
 * @generated
 */
public interface HWSinglePointFaultMetricFormula extends AtpFormulaExpressionString
{
  /**
   * Returns the value of the '<em><b>Lambda Value</b></em>' reference list.
   * The list contents are of type {@link safe10.classmodel.hardware.hwquantitativemeasure.HWFMSingleContribution}.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Lambda Value</em>' reference list isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Lambda Value</em>' reference list.
   * @see safe10.classmodel.hardware.failureformula.FailureformulaPackage#getHWSinglePointFaultMetricFormula_LambdaValue()
   * @model annotation="MetaData guid='{F6526BB1-2C08-4421-86D6-E26E1F1C7467}' id='316600408' EA\040name=''"
   *        annotation="TaggedValues xml.name='LAMBDA-VALUE-REF' xml.namePlural='LAMBDA-VALUE-REFS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1' xml.roleElement='true' xml.roleWrapperElement='true' xml.typeElement='false' xml.typeWrapperElement='false'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   */
  EList<HWFMSingleContribution> getLambdaValue();

} // HWSinglePointFaultMetricFormula
