/**
 */
package safe10.classmodel.hardware.probabilisticmethods;

import java.util.Arrays;
import java.util.Collections;
import java.util.List;

import org.eclipse.emf.common.util.Enumerator;

/**
 * <!-- begin-user-doc -->
 * A representation of the literals of the enumeration '<em><b>HWRF Target Failure Rate Class Enum</b></em>',
 * and utility methods for working with them.
 * <!-- end-user-doc -->
 * <!-- begin-model-doc -->
 * ISO 26262 Part 5 9.4.3.6 -Table 8 (Maximum failure rate classes for a given diagnostic coverage of the hardware part - residual faults).
 * 
 * DM: Dedicated measures
 * RDC: Diagnostic coverage with respect to residual faults
 * 
 * This class describes the threshold for Residual Failure according to ASIL level and identifying Failure Class Rate limit (FRClassx) and Dedicated Measure (DM) if necessary. Notice that RDC is addressing the hwElementResidualDiagnosisCoverage parameter of the HWElementFailureRateClass
 * 
 * Additionally, "OUT-OF-SCOPE" and "ASIL-D and RDC &gt;=99.99%" according to ISO 26262 Part 5 9.4.3.7.
 * <!-- end-model-doc -->
 * @see safe10.classmodel.hardware.probabilisticmethods.ProbabilisticmethodsPackage#getHWRFTargetFailureRateClassEnum()
 * @model annotation="MetaData guid='{1B09D4CD-4BD6-4212-B782-913B78A1FDD2}' id='-552938990' EA\040name='HWRFTargetFailureRateClassEnum'"
 *        annotation="Stereotype Stereotype='enumeration'"
 *        annotation="TaggedValues xml.name='HWRF-TARGET-FAILURE-RATE-CLASS-ENUM' xml.namePlural='HWRF-TARGET-FAILURE-RATE-CLASS-ENUMS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1'"
 *        annotation="EAAdapter metaModelType='SAFE'"
 * @generated
 */
public enum HWRFTargetFailureRateClassEnum implements Enumerator
{
  /**
   * The '<em><b>Out Of Scope</b></em>' literal object.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #OUT_OF_SCOPE_VALUE
   * @generated
   * @ordered
   */
  OUT_OF_SCOPE(0, "OutOfScope", "OUTOFSCOPE"),

  /**
   * The '<em><b>ASIL Dand RDC GTEQ 99 dot 99pct</b></em>' literal object.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #ASIL_DAND_RDC_GTEQ_99_DOT_99PCT_VALUE
   * @generated
   * @ordered
   */
  ASIL_DAND_RDC_GTEQ_99_DOT_99PCT(1, "ASIL_D_and_RDC_GTEQ_99_dot_99pct", "ASIL_D_AND_RDC_GTEQ_99_DOT_99PCT"),

  /**
   * The '<em><b>ASIL Dand RDC GTEQ 99 dot 9pct</b></em>' literal object.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #ASIL_DAND_RDC_GTEQ_99_DOT_9PCT_VALUE
   * @generated
   * @ordered
   */
  ASIL_DAND_RDC_GTEQ_99_DOT_9PCT(2, "ASIL_D_and_RDC_GTEQ_99_dot_9pct", "ASIL_D_AND_RDC_GTEQ_99_DOT_9PCT"),

  /**
   * The '<em><b>ASIL Dand RDC GTEQ 99pct</b></em>' literal object.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #ASIL_DAND_RDC_GTEQ_99PCT_VALUE
   * @generated
   * @ordered
   */
  ASIL_DAND_RDC_GTEQ_99PCT(3, "ASIL_D_and_RDC_GTEQ_99pct", "ASIL_D_AND_RDC_GTEQ_99PCT"),

  /**
   * The '<em><b>ASIL Dand RDC GTEQ 90pct</b></em>' literal object.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #ASIL_DAND_RDC_GTEQ_90PCT_VALUE
   * @generated
   * @ordered
   */
  ASIL_DAND_RDC_GTEQ_90PCT(4, "ASIL_D_and_RDC_GTEQ_90pct", "ASIL_D_AND_RDC_GTEQ_90PCT"),

  /**
   * The '<em><b>ASIL Dand RDC LT 90pct</b></em>' literal object.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #ASIL_DAND_RDC_LT_90PCT_VALUE
   * @generated
   * @ordered
   */
  ASIL_DAND_RDC_LT_90PCT(5, "ASIL_D_and_RDC_LT_90pct", "ASIL_D_AND_RDC_LT_90PCT"),

  /**
   * The '<em><b>ASIL Cand RDC GTEQ 99 dot 9pct</b></em>' literal object.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #ASIL_CAND_RDC_GTEQ_99_DOT_9PCT_VALUE
   * @generated
   * @ordered
   */
  ASIL_CAND_RDC_GTEQ_99_DOT_9PCT(6, "ASIL_C_and_RDC_GTEQ_99_dot_9pct", "ASIL_C_AND_RDC_GTEQ_99_DOT_9PCT"),

  /**
   * The '<em><b>ASIL Cand RDC GTEQ 99pct</b></em>' literal object.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #ASIL_CAND_RDC_GTEQ_99PCT_VALUE
   * @generated
   * @ordered
   */
  ASIL_CAND_RDC_GTEQ_99PCT(7, "ASIL_C_and_RDC_GTEQ_99pct", "ASIL_C_AND_RDC_GTEQ_99PCT"),

  /**
   * The '<em><b>ASIL Cand RDC GTEQ 90pct</b></em>' literal object.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #ASIL_CAND_RDC_GTEQ_90PCT_VALUE
   * @generated
   * @ordered
   */
  ASIL_CAND_RDC_GTEQ_90PCT(8, "ASIL_C_and_RDC_GTEQ_90pct", "ASIL_C_AND_RDC_GTEQ_90PCT"),

  /**
   * The '<em><b>ASIL Cand RDC LT 90pct</b></em>' literal object.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #ASIL_CAND_RDC_LT_90PCT_VALUE
   * @generated
   * @ordered
   */
  ASIL_CAND_RDC_LT_90PCT(9, "ASIL_C_and_RDC_LT_90pct", "ASIL_C_AND_RDC_LT_90PCT"),

  /**
   * The '<em><b>ASIL Band RDC GTEQ 99 dot 9pct</b></em>' literal object.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #ASIL_BAND_RDC_GTEQ_99_DOT_9PCT_VALUE
   * @generated
   * @ordered
   */
  ASIL_BAND_RDC_GTEQ_99_DOT_9PCT(10, "ASIL_B_and_RDC_GTEQ_99_dot_9pct", "ASIL_B_AND_RDC_GTEQ_99_DOT_9PCT"),

  /**
   * The '<em><b>ASIL Band RDC GTEQ 99pct</b></em>' literal object.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #ASIL_BAND_RDC_GTEQ_99PCT_VALUE
   * @generated
   * @ordered
   */
  ASIL_BAND_RDC_GTEQ_99PCT(11, "ASIL_B_and_RDC_GTEQ_99pct", "ASIL_B_AND_RDC_GTEQ_99PCT"),

  /**
   * The '<em><b>ASIL Band RDC GTEQ 90pct</b></em>' literal object.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #ASIL_BAND_RDC_GTEQ_90PCT_VALUE
   * @generated
   * @ordered
   */
  ASIL_BAND_RDC_GTEQ_90PCT(12, "ASIL_B_and_RDC_GTEQ_90pct", "ASIL_B_AND_RDC_GTEQ_90PCT"),

  /**
   * The '<em><b>ASIL Band RDC LT 90pct</b></em>' literal object.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #ASIL_BAND_RDC_LT_90PCT_VALUE
   * @generated
   * @ordered
   */
  ASIL_BAND_RDC_LT_90PCT(13, "ASIL_B_and_RDC_LT_90pct", "ASIL_B_AND_RDC_LT_90PCT");

  /**
   * The '<em><b>Out Of Scope</b></em>' literal value.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of '<em><b>Out Of Scope</b></em>' literal object isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @see #OUT_OF_SCOPE
   * @model name="OutOfScope" literal="OUTOFSCOPE"
   *        annotation="TaggedValues xml.name='OUT-OF-SCOPE' xml.namePlural='OUT-OF-SCOPES' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   * @ordered
   */
  public static final int OUT_OF_SCOPE_VALUE = 0;

  /**
   * The '<em><b>ASIL Dand RDC GTEQ 99 dot 99pct</b></em>' literal value.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of '<em><b>ASIL Dand RDC GTEQ 99 dot 99pct</b></em>' literal object isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @see #ASIL_DAND_RDC_GTEQ_99_DOT_99PCT
   * @model name="ASIL_D_and_RDC_GTEQ_99_dot_99pct" literal="ASIL_D_AND_RDC_GTEQ_99_DOT_99PCT"
   *        annotation="TaggedValues xml.name='ASIL-D-AND-RDC-GTEQ-99-DOT-99-PCT' xml.namePlural='ASIL-D-AND-RDC-GTEQ-99-DOT-99-PCTS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   * @ordered
   */
  public static final int ASIL_DAND_RDC_GTEQ_99_DOT_99PCT_VALUE = 1;

  /**
   * The '<em><b>ASIL Dand RDC GTEQ 99 dot 9pct</b></em>' literal value.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of '<em><b>ASIL Dand RDC GTEQ 99 dot 9pct</b></em>' literal object isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @see #ASIL_DAND_RDC_GTEQ_99_DOT_9PCT
   * @model name="ASIL_D_and_RDC_GTEQ_99_dot_9pct" literal="ASIL_D_AND_RDC_GTEQ_99_DOT_9PCT"
   *        annotation="TaggedValues xml.name='ASIL-D-AND-RDC-GTEQ-99-DOT-9-PCT' xml.namePlural='ASIL-D-AND-RDC-GTEQ-99-DOT-9-PCTS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   * @ordered
   */
  public static final int ASIL_DAND_RDC_GTEQ_99_DOT_9PCT_VALUE = 2;

  /**
   * The '<em><b>ASIL Dand RDC GTEQ 99pct</b></em>' literal value.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of '<em><b>ASIL Dand RDC GTEQ 99pct</b></em>' literal object isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @see #ASIL_DAND_RDC_GTEQ_99PCT
   * @model name="ASIL_D_and_RDC_GTEQ_99pct" literal="ASIL_D_AND_RDC_GTEQ_99PCT"
   *        annotation="TaggedValues xml.name='ASIL-D-AND-RDC-GTEQ-99-PCT' xml.namePlural='ASIL-D-AND-RDC-GTEQ-99-PCTS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   * @ordered
   */
  public static final int ASIL_DAND_RDC_GTEQ_99PCT_VALUE = 3;

  /**
   * The '<em><b>ASIL Dand RDC GTEQ 90pct</b></em>' literal value.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of '<em><b>ASIL Dand RDC GTEQ 90pct</b></em>' literal object isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @see #ASIL_DAND_RDC_GTEQ_90PCT
   * @model name="ASIL_D_and_RDC_GTEQ_90pct" literal="ASIL_D_AND_RDC_GTEQ_90PCT"
   *        annotation="TaggedValues xml.name='ASIL-D-AND-RDC-GTEQ-90-PCT' xml.namePlural='ASIL-D-AND-RDC-GTEQ-90-PCTS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   * @ordered
   */
  public static final int ASIL_DAND_RDC_GTEQ_90PCT_VALUE = 4;

  /**
   * The '<em><b>ASIL Dand RDC LT 90pct</b></em>' literal value.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of '<em><b>ASIL Dand RDC LT 90pct</b></em>' literal object isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @see #ASIL_DAND_RDC_LT_90PCT
   * @model name="ASIL_D_and_RDC_LT_90pct" literal="ASIL_D_AND_RDC_LT_90PCT"
   *        annotation="TaggedValues xml.name='ASIL-D-AND-RDC-LT-90-PCT' xml.namePlural='ASIL-D-AND-RDC-LT-90-PCTS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   * @ordered
   */
  public static final int ASIL_DAND_RDC_LT_90PCT_VALUE = 5;

  /**
   * The '<em><b>ASIL Cand RDC GTEQ 99 dot 9pct</b></em>' literal value.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of '<em><b>ASIL Cand RDC GTEQ 99 dot 9pct</b></em>' literal object isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @see #ASIL_CAND_RDC_GTEQ_99_DOT_9PCT
   * @model name="ASIL_C_and_RDC_GTEQ_99_dot_9pct" literal="ASIL_C_AND_RDC_GTEQ_99_DOT_9PCT"
   *        annotation="TaggedValues xml.name='ASIL-C-AND-RDC-GTEQ-99-DOT-9-PCT' xml.namePlural='ASIL-C-AND-RDC-GTEQ-99-DOT-9-PCTS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   * @ordered
   */
  public static final int ASIL_CAND_RDC_GTEQ_99_DOT_9PCT_VALUE = 6;

  /**
   * The '<em><b>ASIL Cand RDC GTEQ 99pct</b></em>' literal value.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of '<em><b>ASIL Cand RDC GTEQ 99pct</b></em>' literal object isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @see #ASIL_CAND_RDC_GTEQ_99PCT
   * @model name="ASIL_C_and_RDC_GTEQ_99pct" literal="ASIL_C_AND_RDC_GTEQ_99PCT"
   *        annotation="TaggedValues xml.name='ASIL-C-AND-RDC-GTEQ-99-PCT' xml.namePlural='ASIL-C-AND-RDC-GTEQ-99-PCTS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   * @ordered
   */
  public static final int ASIL_CAND_RDC_GTEQ_99PCT_VALUE = 7;

  /**
   * The '<em><b>ASIL Cand RDC GTEQ 90pct</b></em>' literal value.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of '<em><b>ASIL Cand RDC GTEQ 90pct</b></em>' literal object isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @see #ASIL_CAND_RDC_GTEQ_90PCT
   * @model name="ASIL_C_and_RDC_GTEQ_90pct" literal="ASIL_C_AND_RDC_GTEQ_90PCT"
   *        annotation="TaggedValues xml.name='ASIL-C-AND-RDC-GTEQ-90-PCT' xml.namePlural='ASIL-C-AND-RDC-GTEQ-90-PCTS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   * @ordered
   */
  public static final int ASIL_CAND_RDC_GTEQ_90PCT_VALUE = 8;

  /**
   * The '<em><b>ASIL Cand RDC LT 90pct</b></em>' literal value.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of '<em><b>ASIL Cand RDC LT 90pct</b></em>' literal object isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @see #ASIL_CAND_RDC_LT_90PCT
   * @model name="ASIL_C_and_RDC_LT_90pct" literal="ASIL_C_AND_RDC_LT_90PCT"
   *        annotation="TaggedValues xml.name='ASIL-C-AND-RDC-LT-90-PCT' xml.namePlural='ASIL-C-AND-RDC-LT-90-PCTS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   * @ordered
   */
  public static final int ASIL_CAND_RDC_LT_90PCT_VALUE = 9;

  /**
   * The '<em><b>ASIL Band RDC GTEQ 99 dot 9pct</b></em>' literal value.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of '<em><b>ASIL Band RDC GTEQ 99 dot 9pct</b></em>' literal object isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @see #ASIL_BAND_RDC_GTEQ_99_DOT_9PCT
   * @model name="ASIL_B_and_RDC_GTEQ_99_dot_9pct" literal="ASIL_B_AND_RDC_GTEQ_99_DOT_9PCT"
   *        annotation="TaggedValues xml.name='ASIL-B-AND-RDC-GTEQ-99-DOT-9-PCT' xml.namePlural='ASIL-B-AND-RDC-GTEQ-99-DOT-9-PCTS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   * @ordered
   */
  public static final int ASIL_BAND_RDC_GTEQ_99_DOT_9PCT_VALUE = 10;

  /**
   * The '<em><b>ASIL Band RDC GTEQ 99pct</b></em>' literal value.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of '<em><b>ASIL Band RDC GTEQ 99pct</b></em>' literal object isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @see #ASIL_BAND_RDC_GTEQ_99PCT
   * @model name="ASIL_B_and_RDC_GTEQ_99pct" literal="ASIL_B_AND_RDC_GTEQ_99PCT"
   *        annotation="TaggedValues xml.name='ASIL-B-AND-RDC-GTEQ-99-PCT' xml.namePlural='ASIL-B-AND-RDC-GTEQ-99-PCTS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   * @ordered
   */
  public static final int ASIL_BAND_RDC_GTEQ_99PCT_VALUE = 11;

  /**
   * The '<em><b>ASIL Band RDC GTEQ 90pct</b></em>' literal value.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of '<em><b>ASIL Band RDC GTEQ 90pct</b></em>' literal object isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @see #ASIL_BAND_RDC_GTEQ_90PCT
   * @model name="ASIL_B_and_RDC_GTEQ_90pct" literal="ASIL_B_AND_RDC_GTEQ_90PCT"
   *        annotation="TaggedValues xml.name='ASIL-B-AND-RDC-GTEQ-90-PCT' xml.namePlural='ASIL-B-AND-RDC-GTEQ-90-PCTS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   * @ordered
   */
  public static final int ASIL_BAND_RDC_GTEQ_90PCT_VALUE = 12;

  /**
   * The '<em><b>ASIL Band RDC LT 90pct</b></em>' literal value.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of '<em><b>ASIL Band RDC LT 90pct</b></em>' literal object isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @see #ASIL_BAND_RDC_LT_90PCT
   * @model name="ASIL_B_and_RDC_LT_90pct" literal="ASIL_B_AND_RDC_LT_90PCT"
   *        annotation="TaggedValues xml.name='ASIL-B-AND-RDC-LT-90-PCT' xml.namePlural='ASIL-B-AND-RDC-LT-90-PCTS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   * @ordered
   */
  public static final int ASIL_BAND_RDC_LT_90PCT_VALUE = 13;

  /**
   * An array of all the '<em><b>HWRF Target Failure Rate Class Enum</b></em>' enumerators.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private static final HWRFTargetFailureRateClassEnum[] VALUES_ARRAY =
    new HWRFTargetFailureRateClassEnum[]
    {
      OUT_OF_SCOPE,
      ASIL_DAND_RDC_GTEQ_99_DOT_99PCT,
      ASIL_DAND_RDC_GTEQ_99_DOT_9PCT,
      ASIL_DAND_RDC_GTEQ_99PCT,
      ASIL_DAND_RDC_GTEQ_90PCT,
      ASIL_DAND_RDC_LT_90PCT,
      ASIL_CAND_RDC_GTEQ_99_DOT_9PCT,
      ASIL_CAND_RDC_GTEQ_99PCT,
      ASIL_CAND_RDC_GTEQ_90PCT,
      ASIL_CAND_RDC_LT_90PCT,
      ASIL_BAND_RDC_GTEQ_99_DOT_9PCT,
      ASIL_BAND_RDC_GTEQ_99PCT,
      ASIL_BAND_RDC_GTEQ_90PCT,
      ASIL_BAND_RDC_LT_90PCT,
    };

  /**
   * A public read-only list of all the '<em><b>HWRF Target Failure Rate Class Enum</b></em>' enumerators.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public static final List<HWRFTargetFailureRateClassEnum> VALUES = Collections.unmodifiableList(Arrays.asList(VALUES_ARRAY));

  /**
   * Returns the '<em><b>HWRF Target Failure Rate Class Enum</b></em>' literal with the specified literal value.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public static HWRFTargetFailureRateClassEnum get(String literal)
  {
    for (int i = 0; i < VALUES_ARRAY.length; ++i)
    {
      HWRFTargetFailureRateClassEnum result = VALUES_ARRAY[i];
      if (result.toString().equals(literal))
      {
        return result;
      }
    }
    return null;
  }

  /**
   * Returns the '<em><b>HWRF Target Failure Rate Class Enum</b></em>' literal with the specified name.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public static HWRFTargetFailureRateClassEnum getByName(String name)
  {
    for (int i = 0; i < VALUES_ARRAY.length; ++i)
    {
      HWRFTargetFailureRateClassEnum result = VALUES_ARRAY[i];
      if (result.getName().equals(name))
      {
        return result;
      }
    }
    return null;
  }

  /**
   * Returns the '<em><b>HWRF Target Failure Rate Class Enum</b></em>' literal with the specified integer value.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public static HWRFTargetFailureRateClassEnum get(int value)
  {
    switch (value)
    {
      case OUT_OF_SCOPE_VALUE: return OUT_OF_SCOPE;
      case ASIL_DAND_RDC_GTEQ_99_DOT_99PCT_VALUE: return ASIL_DAND_RDC_GTEQ_99_DOT_99PCT;
      case ASIL_DAND_RDC_GTEQ_99_DOT_9PCT_VALUE: return ASIL_DAND_RDC_GTEQ_99_DOT_9PCT;
      case ASIL_DAND_RDC_GTEQ_99PCT_VALUE: return ASIL_DAND_RDC_GTEQ_99PCT;
      case ASIL_DAND_RDC_GTEQ_90PCT_VALUE: return ASIL_DAND_RDC_GTEQ_90PCT;
      case ASIL_DAND_RDC_LT_90PCT_VALUE: return ASIL_DAND_RDC_LT_90PCT;
      case ASIL_CAND_RDC_GTEQ_99_DOT_9PCT_VALUE: return ASIL_CAND_RDC_GTEQ_99_DOT_9PCT;
      case ASIL_CAND_RDC_GTEQ_99PCT_VALUE: return ASIL_CAND_RDC_GTEQ_99PCT;
      case ASIL_CAND_RDC_GTEQ_90PCT_VALUE: return ASIL_CAND_RDC_GTEQ_90PCT;
      case ASIL_CAND_RDC_LT_90PCT_VALUE: return ASIL_CAND_RDC_LT_90PCT;
      case ASIL_BAND_RDC_GTEQ_99_DOT_9PCT_VALUE: return ASIL_BAND_RDC_GTEQ_99_DOT_9PCT;
      case ASIL_BAND_RDC_GTEQ_99PCT_VALUE: return ASIL_BAND_RDC_GTEQ_99PCT;
      case ASIL_BAND_RDC_GTEQ_90PCT_VALUE: return ASIL_BAND_RDC_GTEQ_90PCT;
      case ASIL_BAND_RDC_LT_90PCT_VALUE: return ASIL_BAND_RDC_LT_90PCT;
    }
    return null;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private final int value;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private final String name;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private final String literal;

  /**
   * Only this class can construct instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private HWRFTargetFailureRateClassEnum(int value, String name, String literal)
  {
    this.value = value;
    this.name = name;
    this.literal = literal;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public int getValue()
  {
    return value;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public String getName()
  {
    return name;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public String getLiteral()
  {
    return literal;
  }

  /**
   * Returns the literal value of the enumerator, which is its string representation.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public String toString()
  {
    return literal;
  }
  
} //HWRFTargetFailureRateClassEnum
