/**
 * <copyright>
 * </copyright>
 *
 * $Id$
 */
package safe10.classmodel.hazards;

import eastadl21.east_adl.environment.Environment;

import org.eclipse.emf.common.util.EList;

import safe10.classmodel.requirements.TraceableSpecification;

/**
 * <!-- begin-user-doc -->
 * A representation of the model object '<em><b>Operational Situation</b></em>'.
 * <!-- end-user-doc -->
 *
 * <!-- begin-model-doc -->
 * An operational situation is a scenario that may occur during a vehicles lifetime. Operational situations are formed by contributions of different actors, namely the driver (input of the driver via steering wheel, gas pedal, etc), the environment (e.g. road and lighting conditions), and other participants (pedestrians, other vehicles, etc).
 * 
 * The operational situations and operating modes in which an item's malfunctioning behavior will result in a hazardous event shall be described, both for cases when the vehicle is correctly used and when it is incorrectly used in a foreseeable way 
 * <i><u>
 * </u></i><i><u>Reference: </u></i>
 * ISO 26262-3-7.4.2.1.1
 * ISO 26262-3-Annex.B-TableB.3.
 * <!-- end-model-doc -->
 *
 * <p>
 * The following features are supported:
 * <ul>
 *   <li>{@link safe10.classmodel.hazards.OperationalSituation#getOtherSubjects <em>Other Subjects</em>}</li>
 *   <li>{@link safe10.classmodel.hazards.OperationalSituation#getEnvironment <em>Environment</em>}</li>
 *   <li>{@link safe10.classmodel.hazards.OperationalSituation#getDriver <em>Driver</em>}</li>
 *   <li>{@link safe10.classmodel.hazards.OperationalSituation#getExternalHardware <em>External Hardware</em>}</li>
 *   <li>{@link safe10.classmodel.hazards.OperationalSituation#getOtherParticipants <em>Other Participants</em>}</li>
 * </ul>
 * </p>
 *
 * @see safe10.classmodel.hazards.HazardsPackage#getOperationalSituation()
 * @model annotation="MetaData guid='{FF0A044E-CF76-46f6-8E90-A8791083C522}' id='-1141085200' EA\040name='OperationalSituation'"
 *        annotation="TaggedValues xml.name='OPERATIONAL-SITUATION' xml.namePlural='OPERATIONAL-SITUATIONS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1'"
 *        annotation="EAAdapter metaModelType='SAFE'"
 * @generated
 */
public interface OperationalSituation extends TraceableSpecification
{
  /**
   * Returns the value of the '<em><b>Other Subjects</b></em>' reference list.
   * The list contents are of type {@link safe10.classmodel.hazards.Actor}.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Other Subjects</em>' reference list isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Other Subjects</em>' reference list.
   * @see safe10.classmodel.hazards.HazardsPackage#getOperationalSituation_OtherSubjects()
   * @model annotation="MetaData guid='{2D262B62-EA66-487c-8A97-9A04FC01805A}' id='-1938993912' EA\040name=''"
   *        annotation="TaggedValues xml.name='OTHER-SUBJECTS-REF' xml.namePlural='OTHER-SUBJECTS-REFS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1' xml.roleElement='true' xml.roleWrapperElement='true' xml.typeElement='false' xml.typeWrapperElement='false'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   */
  EList<Actor> getOtherSubjects();

  /**
   * Returns the value of the '<em><b>Environment</b></em>' reference.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Environment</em>' reference isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Environment</em>' reference.
   * @see #setEnvironment(Environment)
   * @see safe10.classmodel.hazards.HazardsPackage#getOperationalSituation_Environment()
   * @model annotation="MetaData guid='{924D0175-53D0-4754-BDAF-48F91509F4B1}' id='-1694934980' EA\040name=''"
   *        annotation="TaggedValues xml.name='ENVIRONMENT-REF' xml.namePlural='ENVIRONMENT-REFS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1' xml.roleElement='true' xml.roleWrapperElement='false' xml.typeElement='false' xml.typeWrapperElement='false'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   */
  Environment getEnvironment();

  /**
   * Sets the value of the '{@link safe10.classmodel.hazards.OperationalSituation#getEnvironment <em>Environment</em>}' reference.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Environment</em>' reference.
   * @see #getEnvironment()
   * @generated
   */
  void setEnvironment(Environment value);

  /**
   * Returns the value of the '<em><b>Driver</b></em>' reference.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Driver</em>' reference isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Driver</em>' reference.
   * @see #setDriver(Actor)
   * @see safe10.classmodel.hazards.HazardsPackage#getOperationalSituation_Driver()
   * @model annotation="MetaData guid='{64B412BC-A1D4-4742-AEFF-10B66BCA6497}' id='845963527' EA\040name=''"
   *        annotation="TaggedValues xml.name='DRIVER-REF' xml.namePlural='DRIVER-REFS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1' xml.roleElement='true' xml.roleWrapperElement='false' xml.typeElement='false' xml.typeWrapperElement='false'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   */
  Actor getDriver();

  /**
   * Sets the value of the '{@link safe10.classmodel.hazards.OperationalSituation#getDriver <em>Driver</em>}' reference.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Driver</em>' reference.
   * @see #getDriver()
   * @generated
   */
  void setDriver(Actor value);

  /**
   * Returns the value of the '<em><b>External Hardware</b></em>' reference list.
   * The list contents are of type {@link safe10.classmodel.hazards.Actor}.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>External Hardware</em>' reference list isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>External Hardware</em>' reference list.
   * @see safe10.classmodel.hazards.HazardsPackage#getOperationalSituation_ExternalHardware()
   * @model annotation="MetaData guid='{05885B18-6E67-46e1-860E-EB0161202715}' id='1252791427' EA\040name=''"
   *        annotation="TaggedValues xml.name='EXTERNAL-HARDWARE-REF' xml.namePlural='EXTERNAL-HARDWARE-REFS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1' xml.roleElement='true' xml.roleWrapperElement='true' xml.typeElement='false' xml.typeWrapperElement='false'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   */
  EList<Actor> getExternalHardware();

  /**
   * Returns the value of the '<em><b>Other Participants</b></em>' reference list.
   * The list contents are of type {@link safe10.classmodel.hazards.Actor}.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Other Participants</em>' reference list isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Other Participants</em>' reference list.
   * @see safe10.classmodel.hazards.HazardsPackage#getOperationalSituation_OtherParticipants()
   * @model annotation="MetaData guid='{FE5BE433-EC89-488f-9704-5F2F267A2028}' id='1686740702' EA\040name=''"
   *        annotation="TaggedValues xml.name='OTHER-PARTICIPANTS-REF' xml.namePlural='OTHER-PARTICIPANTS-REFS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1' xml.roleElement='true' xml.roleWrapperElement='true' xml.typeElement='false' xml.typeWrapperElement='false'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   */
  EList<Actor> getOtherParticipants();

} // OperationalSituation
