/**
 * <copyright>
 * </copyright>
 *
 * $Id$
 */
package safe10.classmodel.requirements;


/**
 * <!-- begin-user-doc -->
 * A representation of the model object '<em><b>Functional Safety Requirement</b></em>'.
 * <!-- end-user-doc -->
 *
 * <!-- begin-model-doc -->
 * FunctionalSafetyRequirements are used to specify
 * <ul>
 * 	<li>implementation-independent safety behavior</li>
 * 	<li>implementation-independent safety measures.</li>
 * </ul>
 * FunctionalSafetyRequirements shall contain safety-related attributes.
 * At least one functional safety requirement shall be specified for each safety goal. 
 * FunctionalSafetyRequirements are allocated to the FunctionComponent of the item.
 * A safety goal shall be determined for each hazardous event with an ASIL evaluated in the hazard analysis. If similar safety goals are determined, these may be combined into one safety goal. 
 * 
 * <i><u>Constraint</u></i>:
 * HasAsilDecomposed shall only be set if attribute redundancy is set true. 
 * <b><i><u>
 * </u></i></b><i><u>Reference</u></i><b><i><u>: </u></i></b>
 * ISO 26262-1-1.53
 * ISO 26262-3: 8.4.2.3
 * ISO 26262-3-7.4.4.3
 * <!-- end-model-doc -->
 *
 * <p>
 * The following features are supported:
 * <ul>
 *   <li>{@link safe10.classmodel.requirements.FunctionalSafetyRequirement#getRequirementKind <em>Requirement Kind</em>}</li>
 *   <li>{@link safe10.classmodel.requirements.FunctionalSafetyRequirement#getRedundancy <em>Redundancy</em>}</li>
 *   <li>{@link safe10.classmodel.requirements.FunctionalSafetyRequirement#getIsSafetyGoal <em>Is Safety Goal</em>}</li>
 * </ul>
 * </p>
 *
 * @see safe10.classmodel.requirements.RequirementsPackage#getFunctionalSafetyRequirement()
 * @model annotation="MetaData guid='{92F8CEC9-C638-48e7-8151-15120713DCDD}' id='-204502646' EA\040name='FunctionalSafetyRequirement'"
 *        annotation="TaggedValues xml.name='FUNCTIONAL-SAFETY-REQUIREMENT' xml.namePlural='FUNCTIONAL-SAFETY-REQUIREMENTS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1'"
 *        annotation="EAAdapter metaModelType='SAFE'"
 * @generated
 */
public interface FunctionalSafetyRequirement extends HasAsilDecomposed, AbstractSafetyRequirement, HasEmergencyOperationTimeInterval, HasFaultTolerantTimeInterval
{
  /**
   * Returns the value of the '<em><b>Requirement Kind</b></em>' attribute.
   * The default value is <code>"QUANTITATIVE"</code>.
   * The literals are from the enumeration {@link safe10.classmodel.requirements.RequirementKind}.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Requirement Kind</em>' attribute isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Requirement Kind</em>' attribute.
   * @see safe10.classmodel.requirements.RequirementKind
   * @see #isSetRequirementKind()
   * @see #unsetRequirementKind()
   * @see #setRequirementKind(RequirementKind)
   * @see safe10.classmodel.requirements.RequirementsPackage#getFunctionalSafetyRequirement_RequirementKind()
   * @model default="QUANTITATIVE" unsettable="true" required="true"
   *        annotation="MetaData guid='{1B6ADE89-DB2E-4dfd-9E8C-424148EFD865}' id='-1148505601' EA\040name='requirementKind'"
   *        annotation="TaggedValues xml.name='REQUIREMENT-KIND' xml.namePlural='REQUIREMENT-KINDS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1' xml.roleElement='true' xml.roleWrapperElement='false' xml.typeElement='false' xml.typeWrapperElement='false'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   */
  RequirementKind getRequirementKind();

  /**
   * Sets the value of the '{@link safe10.classmodel.requirements.FunctionalSafetyRequirement#getRequirementKind <em>Requirement Kind</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Requirement Kind</em>' attribute.
   * @see safe10.classmodel.requirements.RequirementKind
   * @see #isSetRequirementKind()
   * @see #RequirementKind()
   * @see #getRequirementKind()
   * @generated
   */
  void setRequirementKind(RequirementKind value);

  /**
   * Unsets the value of the '{@link safe10.classmodel.requirements.FunctionalSafetyRequirement#getRequirementKind <em>Requirement Kind</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #isSetRequirementKind()
   * @see #getRequirementKind()
   * @see #setRequirementKind(RequirementKind)
   * @generated
   */
  void unsetRequirementKind();

  /**
   * Returns whether the value of the '{@link safe10.classmodel.requirements.FunctionalSafetyRequirement#getRequirementKind <em>Requirement Kind</em>}' attribute is set.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @return whether the value of the '<em>Requirement Kind</em>' attribute is set.
   * @see #RequirementKind()
   * @see #getRequirementKind()
   * @see #setRequirementKind(RequirementKind)
   * @generated
   */
  boolean isSetRequirementKind();

  /**
   * Returns the value of the '<em><b>Redundancy</b></em>' attribute.
   * The default value is <code>"false"</code>.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Redundancy</em>' attribute isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Redundancy</em>' attribute.
   * @see #isSetRedundancy()
   * @see #unsetRedundancy()
   * @see #setRedundancy(Boolean)
   * @see safe10.classmodel.requirements.RequirementsPackage#getFunctionalSafetyRequirement_Redundancy()
   * @model default="false" unsettable="true" dataType="safe10.classmodel.commonstructure.datatypes.Boolean" required="true"
   *        annotation="MetaData guid='{A642DE52-428E-4eef-BE9F-A3DF25719C6D}' id='507364488' EA\040name='redundancy'"
   *        annotation="TaggedValues xml.name='REDUNDANCY' xml.namePlural='REDUNDANCYS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1' xml.roleElement='true' xml.roleWrapperElement='false' xml.typeElement='false' xml.typeWrapperElement='false'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   */
  Boolean getRedundancy();

  /**
   * Sets the value of the '{@link safe10.classmodel.requirements.FunctionalSafetyRequirement#getRedundancy <em>Redundancy</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Redundancy</em>' attribute.
   * @see #isSetRedundancy()
   * @see #Redundancy()
   * @see #getRedundancy()
   * @generated
   */
  void setRedundancy(Boolean value);

  /**
   * Unsets the value of the '{@link safe10.classmodel.requirements.FunctionalSafetyRequirement#getRedundancy <em>Redundancy</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #isSetRedundancy()
   * @see #getRedundancy()
   * @see #setRedundancy(Boolean)
   * @generated
   */
  void unsetRedundancy();

  /**
   * Returns whether the value of the '{@link safe10.classmodel.requirements.FunctionalSafetyRequirement#getRedundancy <em>Redundancy</em>}' attribute is set.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @return whether the value of the '<em>Redundancy</em>' attribute is set.
   * @see #Redundancy()
   * @see #getRedundancy()
   * @see #setRedundancy(Boolean)
   * @generated
   */
  boolean isSetRedundancy();

  /**
   * Returns the value of the '<em><b>Is Safety Goal</b></em>' attribute.
   * The default value is <code>"false"</code>.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Is Safety Goal</em>' attribute isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Is Safety Goal</em>' attribute.
   * @see #isSetIsSafetyGoal()
   * @see #unsetIsSafetyGoal()
   * @see #setIsSafetyGoal(Boolean)
   * @see safe10.classmodel.requirements.RequirementsPackage#getFunctionalSafetyRequirement_IsSafetyGoal()
   * @model default="false" unsettable="true" dataType="safe10.classmodel.commonstructure.datatypes.Boolean" required="true"
   *        annotation="MetaData guid='{8E92F3CC-33AD-4033-8D10-D9DF27D4399F}' id='1098451751' EA\040name='isSafetyGoal'"
   *        annotation="TaggedValues xml.name='IS-SAFETY-GOAL' xml.namePlural='IS-SAFETY-GOALS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1' xml.roleElement='true' xml.roleWrapperElement='false' xml.typeElement='false' xml.typeWrapperElement='false'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   */
  Boolean getIsSafetyGoal();

  /**
   * Sets the value of the '{@link safe10.classmodel.requirements.FunctionalSafetyRequirement#getIsSafetyGoal <em>Is Safety Goal</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Is Safety Goal</em>' attribute.
   * @see #isSetIsSafetyGoal()
   * @see #IsSafetyGoal()
   * @see #getIsSafetyGoal()
   * @generated
   */
  void setIsSafetyGoal(Boolean value);

  /**
   * Unsets the value of the '{@link safe10.classmodel.requirements.FunctionalSafetyRequirement#getIsSafetyGoal <em>Is Safety Goal</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #isSetIsSafetyGoal()
   * @see #getIsSafetyGoal()
   * @see #setIsSafetyGoal(Boolean)
   * @generated
   */
  void unsetIsSafetyGoal();

  /**
   * Returns whether the value of the '{@link safe10.classmodel.requirements.FunctionalSafetyRequirement#getIsSafetyGoal <em>Is Safety Goal</em>}' attribute is set.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @return whether the value of the '<em>Is Safety Goal</em>' attribute is set.
   * @see #IsSafetyGoal()
   * @see #getIsSafetyGoal()
   * @see #setIsSafetyGoal(Boolean)
   * @generated
   */
  boolean isSetIsSafetyGoal();

} // FunctionalSafetyRequirement
