package org.safe.metamodel10.common.util;

import org.eclipse.emf.common.util.URI;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.EStructuralFeature;
import org.eclipse.sphinx.emf.resource.ExtendedResourceAdapter;

public class ExtendedSAFEResourceAdapter extends ExtendedResourceAdapter {

	/**
	 * Arbitrary scheme for SAFE URIs enabling to reference SAFE elements without having to precise the
	 * files in which they are located.
	 */
	public static final String SAFE_SCHEME = "safe"; //$NON-NLS-1$

	/*
	 * @see org.eclipse.sphinx.emf.resource.ExtendedResourceAdapter#getURI(org.eclipse.emf.ecore.EObject,
	 * org.eclipse.emf.ecore.EStructuralFeature, org.eclipse.emf.ecore.EObject)
	 */
	@Override
	public URI getURI(EObject oldOwner, EStructuralFeature oldFeature, EObject eObject) {
		URI uri = super.getURI(oldOwner, oldFeature, eObject);
		// Make sure that cross-document references to SAFE 2.0 resources are fragment-based
		return createSAFEURI(uri.fragment());
	}

	/**
	 * Creates a fragment-based SAFE0 {@link URI} from given {@link URI} fragment.
	 * 
	 * @param uriFragment
	 *            The {@link URI} fragment the URI to handled.
	 * @return The resulting fragment-based SAFE {@link URI}.
	 */
	protected static URI createSAFEURI(String uriFragment) {
		if (uriFragment != null && uriFragment.length() > 0) {
			return URI.createURI(SAFE_SCHEME + URI_SCHEME_SEPARATOR + URI_SEGMENT_SEPARATOR + URI_FRAGMENT_SEPARATOR + uriFragment, true);
		}
		return null;
	}
}