/**
 */
package org.safe.metamodel10.common.util;

import org.eatop.eel.common.metamodel.EastADLReleaseDescriptor;
import org.artop.aal.common.metamodel.AutosarReleaseDescriptor;
import autosar40.util.Autosar40ReleaseDescriptor;
import eastadl21.util.Eastadl21ReleaseDescriptor;
import org.eclipse.core.runtime.Assert;
import org.eclipse.emf.common.util.URI;

import org.eclipse.emf.ecore.EPackage;
import org.eclipse.emf.ecore.impl.EPackageRegistryImpl;
import org.eclipse.emf.ecore.resource.Resource;

import org.eclipse.emf.ecore.resource.impl.ResourceFactoryImpl;
import org.eclipse.emf.ecore.util.ExtendedMetaData;
import org.eclipse.emf.ecore.xmi.XMIResource;
import org.eclipse.emf.ecore.xmi.XMLResource;
import org.eclipse.sphinx.emf.resource.BasicMigrationExtendedMetaData;
import org.safe.ide.metamodel.SAFEReleaseDescriptor;

/**
 * <!-- begin-user-doc -->
 * The <b>Resource Factory</b> associated with the package.
 * <!-- end-user-doc -->
 * @see org.safe.metamodel10.common.util.Safe10ResourceImpl
 * @generated
 */
public abstract class SafeResourceFactoryImpl extends ResourceFactoryImpl {
	
	protected ExtendedMetaData extendedMetaData;
	
	/**
	 * The {@link SAFEReleaseDescriptor SAFE release} this {@link Resource.Factory resource factory} is dedicated
	 * to.
	 */
	protected SAFEReleaseDescriptor safeRelease;
	
	/**
	 * Creates an instance of the resource factory.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public SafeResourceFactoryImpl(SAFEReleaseDescriptor safeRelease) {
		Assert.isNotNull(safeRelease);
		//Assert.isNotNull(safeRelease.getRootEPackage());

		this.safeRelease = safeRelease;

		extendedMetaData = createExtendedMetaData();
	}
	
	/**
	 * Creates and initializes an {@link ExtendedMetaData} instance to be used on {@link XMLResource resources} created
	 * with this {@link Resource.Factory resource factory}.
	 * 
	 * @return The newly created and initialized {@link ExtendedMetaData} instance.
	 */
	protected ExtendedMetaData createExtendedMetaData() {
		// Create and initialize migration-enabled extended meta data enabling SAFE resources whose version is not
		// the same but compatible with that of current SAFE metamodel implementation to be loaded
		BasicMigrationExtendedMetaData extendedMetaData = new BasicMigrationExtendedMetaData(new EPackageRegistryImpl(EPackage.Registry.INSTANCE)) {
			@Override
			public String getNamespace(EPackage ePackage) {
				// Is given EPackage an EPackage of an EAST-ADL metamodel?
				String uri = ePackage.getNsURI();
				if (uri != null && uri.startsWith(EastADLReleaseDescriptor.BASE_NAMESPACE)) {
					// Suppress individual sub EPackage namespaces; always use namespace of current EAST-ADL release
					return Eastadl21ReleaseDescriptor.INSTANCE.getNamespace();
				} 
				else if (uri != null && uri.startsWith(AutosarReleaseDescriptor.BASE_NAMESPACE)) {
					// Suppress individual sub EPackage namespaces; always use namespace of current EAST-ADL release
					return Autosar40ReleaseDescriptor.INSTANCE.getNamespace();
				}else {
					return super.getNamespace(ePackage);
				}
			}

		};

		//extendedMetaData.putPackage(safeRelease.getNamespace(), safeRelease.getRootEPackage());
		for (java.net.URI compatibleNamespaceURI : safeRelease.getCompatibleNamespaceURIs()) {
			extendedMetaData.putPackage(compatibleNamespaceURI.toString(), safeRelease.getRootEPackage());
		}
		return extendedMetaData;
	}

	

} //Safe10ResourceFactoryImpl
